@@ -15,3 +15,11 @@ from fmdt.args import (
     Args,
 )
 
+from fmdt.truth import (
+    HumanDetection,
+    read_human_detection_csv,
+    init_ground_truth
+)
+
+# from fmdt.truth import HumanDetection
+
